@@ -1,14 +1,10 @@
 use std::string::FromUtf8Error;
 use thiserror::Error;
-use warp::reject::Reject;
 
 pub type MultihookResult<T> = Result<T, MultihookError>;
 
 #[derive(Error, Debug)]
 pub enum MultihookError {
-    #[error(transparent)]
-    Warp(#[from] warp::Error),
-
     #[error("Failed to parse body as utf8 string {0}")]
     UTF8Error(#[from] FromUtf8Error),
 
@@ -23,6 +19,7 @@ pub enum MultihookError {
 
     #[error(transparent)]
     ConfigError(#[from] config::ConfigError),
-}
 
-impl Reject for MultihookError {}
+    #[error(transparent)]
+    Hyper(#[from] hyper::Error),
+}
